@@ -54,6 +54,10 @@ using namespace SPIRV;
 using namespace llvm;
 using namespace spv;
 
+namespace SPIRV {
+class BuiltinCallMutator;
+} // namespace SPIRV
+
 namespace OCLUtil {
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -94,11 +98,19 @@ enum OCLScopeKind {
 // To avoid any inconsistence here, constants are explicitly initialized with
 // the corresponding constants from 'std::memory_order' enum.
 enum OCLMemOrderKind {
+#if __cplusplus >= 202002L
+  OCLMO_relaxed = std::memory_order_relaxed,
+  OCLMO_acquire = std::memory_order_acquire,
+  OCLMO_release = std::memory_order_release,
+  OCLMO_acq_rel = std::memory_order_acq_rel,
+  OCLMO_seq_cst = std::memory_order_seq_cst
+#else
   OCLMO_relaxed = std::memory_order::memory_order_relaxed,
   OCLMO_acquire = std::memory_order::memory_order_acquire,
   OCLMO_release = std::memory_order::memory_order_release,
   OCLMO_acq_rel = std::memory_order::memory_order_acq_rel,
   OCLMO_seq_cst = std::memory_order::memory_order_seq_cst
+#endif
 };
 
 enum IntelFPGAMemoryAccessesVal {
@@ -154,12 +166,12 @@ struct OCLBuiltinTransInfo {
   std::string MangledName;
   std::string Postfix; // Postfix to be added
   /// Postprocessor of operands
-  std::function<void(std::vector<Value *> &)> PostProc;
+  std::function<void(BuiltinCallMutator &)> PostProc;
   Type *RetTy;      // Return type of the translated function
   bool IsRetSigned; // When RetTy is int, determines if extensions
                     // on it should be a sext or zet.
   OCLBuiltinTransInfo() : RetTy(nullptr), IsRetSigned(false) {
-    PostProc = [](std::vector<Value *> &) {};
+    PostProc = [](BuiltinCallMutator &) {};
   }
 };
 
@@ -440,18 +452,19 @@ std::tuple<unsigned short, unsigned char, unsigned char>
 decodeOCLVer(unsigned Ver);
 
 /// Decode a MDNode assuming it contains three integer constants.
-void decodeMDNode(MDNode *N, unsigned &X, unsigned &Y, unsigned &Z);
+SmallVector<unsigned, 3> decodeMDNode(MDNode *N);
 
 /// Get full path from debug info metadata
 /// Return empty string if the path is not available.
 template <typename T> std::string getFullPath(const T *Scope) {
   if (!Scope)
     return std::string();
-  std::string Filename = Scope->getFilename().str();
-  if (sys::path::is_absolute(Filename))
-    return Filename;
+  StringRef Filename = Scope->getFilename();
+  auto Style = sys::path::Style::native;
+  if (sys::path::is_absolute(Filename, Style))
+    return Filename.str();
   SmallString<16> DirName = Scope->getDirectory();
-  sys::path::append(DirName, sys::path::Style::posix, Filename);
+  sys::path::append(DirName, Style, Filename.str());
   return DirName.str().str();
 }
 
@@ -485,20 +498,6 @@ inline OCLMemOrderKind mapSPIRVMemOrderToOCL(unsigned Sema) {
   return OCLMemOrderMap::rmap(extractSPIRVMemOrderSemantic(Sema));
 }
 
-/// Mutate call instruction to call OpenCL builtin function.
-CallInst *mutateCallInstOCL(
-    Module *M, CallInst *CI,
-    std::function<std::string(CallInst *, std::vector<Value *> &)> ArgMutate,
-    AttributeList *Attrs = nullptr);
-
-/// Mutate call instruction to call OpenCL builtin function.
-Instruction *mutateCallInstOCL(
-    Module *M, CallInst *CI,
-    std::function<std::string(CallInst *, std::vector<Value *> &, Type *&RetTy)>
-        ArgMutate,
-    std::function<Instruction *(CallInst *)> RetMutate,
-    AttributeList *Attrs = nullptr, bool TakeFuncName = false);
-
 /// If the value is a special type initializer (something that bitcasts from
 /// spirv.ConstantSampler to spirv.Sampler or likewise for PipeStorage), get the
 /// original type initializer, unwrap the bitcast. Otherwise, return nullptr.
@@ -509,7 +508,7 @@ bool isEnqueueKernelBI(const StringRef MangledName);
 bool isKernelQueryBI(const StringRef MangledName);
 
 /// Check that the type is the sampler_t
-bool isSamplerStructTy(StructType *Ty);
+bool isSamplerTy(Type *Ty);
 
 // Checks if the binary operator is an unfused fmul + fadd instruction.
 bool isUnfusedMulAdd(BinaryOperator *B);
@@ -522,6 +521,8 @@ std::string getIntelSubgroupBlockDataPostfix(unsigned ElementBitSize,
 
 void insertImageNameAccessQualifier(SPIRVAccessQualifierKind Acc,
                                     std::string &Name);
+
+std::unique_ptr<SPIRV::BuiltinFuncMangleInfo> makeMangler(Function &F);
 } // namespace OCLUtil
 
 using namespace OCLUtil;
@@ -531,7 +532,7 @@ template <class KeyTy, class ValTy, class Identifier = void>
 Instruction *
 getOrCreateSwitchFunc(StringRef MapName, Value *V,
                       const SPIRVMap<KeyTy, ValTy, Identifier> &Map,
-                      bool IsReverse, Optional<int> DefaultCase,
+                      bool IsReverse, std::optional<int> DefaultCase,
                       Instruction *InsertPoint, int KeyMask = 0) {
   static_assert(std::is_convertible<KeyTy, int>::value &&
                     std::is_convertible<ValTy, int>::value,
@@ -594,7 +595,7 @@ getOrCreateSwitchFunc(StringRef MapName, Value *V,
 /// \returns \c Value corresponding to SPIR-V Scope equivalent to OpenCL
 ///          memory_scope passed in \arg MemScope
 Value *transOCLMemScopeIntoSPIRVScope(Value *MemScope,
-                                      Optional<int> DefaultCase,
+                                      std::optional<int> DefaultCase,
                                       Instruction *InsertBefore);
 
 /// Performs conversion from OpenCL memory_order into SPIR-V Memory Semantics.
@@ -611,7 +612,7 @@ Value *transOCLMemScopeIntoSPIRVScope(Value *MemScope,
 /// \returns \c Value corresponding to SPIR-V Memory Semantics equivalent to
 ///          OpenCL memory_order passed in \arg MemOrder
 Value *transOCLMemOrderIntoSPIRVMemorySemantics(Value *MemOrder,
-                                                Optional<int> DefaultCase,
+                                                std::optional<int> DefaultCase,
                                                 Instruction *InsertBefore);
 
 /// Performs conversion from SPIR-V Scope into OpenCL memory_scope.
